@@ -1,23 +1,26 @@
-from __future__ import print_function
-from __future__ import division
-from builtins import object
-import pytest
+from __future__ import division, print_function
+
 import os
+import pickle
+from builtins import object
 
 import astropy.units as u
 import numpy as np
-import pickle
-
-from astromodels.functions.function import FunctionMeta, Function1D, Function2D, FunctionDefinitionError, \
-    UnknownParameter, DesignViolation, get_function, get_function_class, UnknownFunction, list_functions
-from astromodels.functions.functions import Powerlaw, Line
-from astromodels.functions.functions_2D import Gaussian_on_sphere, SpatialTemplate_2D
-from astromodels.functions.functions_3D import Continuous_injection_diffusion
-from astromodels.functions import function as function_module
-
+import pytest
 from astropy.io import fits
 from future.utils import with_metaclass
 
+from astromodels.functions import (Continuous_injection_diffusion,
+                                   Gaussian_on_sphere, Line, Powerlaw,
+                                   SpatialTemplate_2D)
+from astromodels.functions import function as function_module
+from astromodels.functions.function import (DesignViolation, Function1D,
+                                            Function2D,
+                                            FunctionDefinitionError,
+                                            FunctionMeta, UnknownFunction,
+                                            UnknownParameter, get_function,
+                                            get_function_class, list_functions)
+
 __author__ = 'giacomov'
 
 
@@ -355,7 +358,6 @@ def test_function_meta():
             def evaluate(self, x, a, b, c):
                 return a * x + b + c
 
-
     with pytest.raises(AssertionError):
         # Docstring lacking description
 
@@ -546,7 +548,7 @@ def test_function_values():
 
     # Test basic functionalities
 
-    assert my_function(1.0)==2
+    assert my_function(1.0) == 2
 
     my_function.a = 2.5
 
@@ -561,8 +563,9 @@ def test_function_values():
     my_function.a.value = 2.0
     my_function.b.value = 1.0
 
-    assert np.all(my_function([1,2,3]) == np.array([3.0, 5.0, 7.0]))
-    assert np.all(my_function(np.array([3, 4, 5])) == np.array([7.0, 9.0, 11.0]))
+    assert np.all(my_function([1, 2, 3]) == np.array([3.0, 5.0, 7.0]))
+    assert np.all(my_function(
+        np.array([3, 4, 5])) == np.array([7.0, 9.0, 11.0]))
 
 
 def test_function_values_units():
@@ -596,7 +599,8 @@ def test_function_values_units():
     my_function.a.value = 2.0 * diff_flux / u.keV
     my_function.b.value = 1.0 * diff_flux
 
-    assert np.all(my_function([1, 2, 3] * u.keV) == np.array([3.0, 5.0, 7.0]) * diff_flux)
+    assert np.all(my_function([1, 2, 3] * u.keV) ==
+                  np.array([3.0, 5.0, 7.0]) * diff_flux)
 
     # Using one unit for each element will fail
 
@@ -605,12 +609,13 @@ def test_function_values_units():
 
         _ = my_function([1 * u.keV, 2 * u.keV, 3 * u.keV])
 
-    assert np.all(my_function(np.array([3, 4, 5]) * u.keV) == np.array([7.0, 9.0, 11.0]) * diff_flux)
+    assert np.all(my_function(
+        np.array([3, 4, 5]) * u.keV) == np.array([7.0, 9.0, 11.0]) * diff_flux)
 
     # Now test that an error is raised if units are not intelligible
     with pytest.raises(TypeError):
 
-        _ = my_function.set_units("non_existent","non_existent")
+        _ = my_function.set_units("non_existent", "non_existent")
 
 
 def test_function_composition():
@@ -624,7 +629,7 @@ def test_function_composition():
 
     composite.set_units(u.keV, 1.0 / (u.keV * u.cm**2 * u.s))
 
-    for x in ([1,2,3,4],[1,2,3,4] * u.keV, 1.0, np.array([1.0, 2.0, 3.0, 4.0])):
+    for x in ([1, 2, 3, 4], [1, 2, 3, 4] * u.keV, 1.0, np.array([1.0, 2.0, 3.0, 4.0])):
 
         assert np.all(composite(x) == line(x) + powerlaw(x))
 
@@ -653,7 +658,7 @@ def test_function_composition():
     # test power
     composite = po**li
 
-    assert composite(2.25)  == po(2.25)**li(2.25)
+    assert composite(2.25) == po(2.25)**li(2.25)
 
     # test negation
     neg_po = -po
@@ -687,7 +692,8 @@ def test_function_composition():
     # Composite of composite
     composite = po*li + po - li + 2*po / li
 
-    assert composite(2.25) == po(2.25) * li(2.25) + po(2.25) - li(2.25) + 2*po(2.25) / li(2.25)
+    assert composite(2.25) == po(2.25) * li(2.25) + \
+        po(2.25) - li(2.25) + 2*po(2.25) / li(2.25)
 
     print(composite)
 
@@ -785,126 +791,126 @@ def test_function2D():
     c = Gaussian_on_sphere()
 
     f1 = c(1, 1)
-    assert np.isclose( f1, 38.285617800653434, rtol=1e-10)
-    
+    assert np.isclose(f1, 38.285617800653434, rtol=1e-10)
 
     a = np.array([1.0, 2.0])
 
     fa = c(a, a)
-    assert np.isclose( fa, [3.82856178e+01, 2.35952748e-04], rtol=1e-10).all()
+    assert np.isclose(fa, [3.82856178e+01, 2.35952748e-04], rtol=1e-10).all()
 
     c.set_units(u.deg, u.deg, 1.0 / u.deg**2)
 
     f1d = c(1 * u.deg, 1.0 * u.deg)
-    assert np.isclose( f1d.value, 38.285617800653434, rtol=1e-10)
+    assert np.isclose(f1d.value, 38.285617800653434, rtol=1e-10)
     assert f1d.unit == u.deg**-2
 
     assert c.x_unit == u.deg
     assert c.y_unit == u.deg
     assert c.z_unit == u.deg**-2
 
-    assert c.get_total_spatial_integral( 1 ) == 1
-    assert np.isclose( c.get_total_spatial_integral( [1,1] ) ,  [1,1], rtol=1e-10).all()
-    
+    assert c.get_total_spatial_integral(1) == 1
+    assert np.isclose(c.get_total_spatial_integral(
+        [1, 1]),  [1, 1], rtol=1e-10).all()
 
     with pytest.raises(TypeError):
 
         c.set_units("not existent", u.deg, u.keV)
 
 
-
 def test_function3D():
 
     c = Continuous_injection_diffusion()
 
     f1 = c(1, 1, 1)
-    assert np.isclose(f1, 134.95394313247866, rtol = 1e-10)
-    
+    assert np.isclose(f1, 134.95394313247866, rtol=1e-10)
+
     a = np.array([1.0, 2.0])
 
     fa = c(a, a, a)
-    assert np.isclose( fa,  [[134.95394313, 132.19796573], [ 25.40751507, 27.321443  ]], rtol=1e-10).all()
+    assert np.isclose(fa,  [[134.95394313, 132.19796573], [
+                      25.40751507, 27.321443]], rtol=1e-10).all()
 
     c.set_units(u.deg, u.deg, u.keV, 1.0 / u.deg**2)
 
     f1d = c(1 * u.deg, 1.0 * u.deg, 1.0 * u.keV)
-    assert np.isclose(f1d.value, 134.95394313247866, rtol = 1e-10)
+    assert np.isclose(f1d.value, 134.95394313247866, rtol=1e-10)
     assert f1d.unit == u.deg**-2
-   
 
     assert c.x_unit == u.deg
     assert c.y_unit == u.deg
     assert c.z_unit == u.keV
     assert c.w_unit == u.deg**-2
 
-    assert c.get_total_spatial_integral( 1 ) == 1
-    assert np.isclose( c.get_total_spatial_integral( [1,1] ) ,  [1,1], rtol=1e-10).all()
+    assert c.get_total_spatial_integral(1) == 1
+    assert np.isclose(c.get_total_spatial_integral(
+        [1, 1]),  [1, 1], rtol=1e-10).all()
 
     with pytest.raises(TypeError):
 
-        c.set_units("not existent", u.deg, u.keV, 1.0 / (u.keV * u.s * u.deg**2 * u.cm**2))
+        c.set_units("not existent", u.deg, u.keV, 1.0 /
+                    (u.keV * u.s * u.deg**2 * u.cm**2))
 
 
 def test_spatial_template_2D():
 
-    #make the fits files with templates to test.
+    # make the fits files with templates to test.
     cards = {
-      "SIMPLE": "T",                     
-      "BITPIX": -32,
-      "NAXIS" : 2,
-      "NAXIS1": 360,
-      "NAXIS2": 360,
-      "DATE": '2018-06-15',  
-      "CUNIT1": 'deg', 
-      "CRVAL1":  83,
-      "CRPIX1": 0,
-      "CDELT1": -0.0166667, 
-      "CUNIT2": 'deg',
-      "CRVAL2": -2.0,
-      "CRPIX2": 0,
-      "CDELT2": 0.0166667,
-      "CTYPE1": 'GLON-CAR',
-      "CTYPE2": 'GLAT-CAR' }
+        "SIMPLE": "T",
+        "BITPIX": -32,
+        "NAXIS": 2,
+        "NAXIS1": 360,
+        "NAXIS2": 360,
+        "DATE": '2018-06-15',
+        "CUNIT1": 'deg',
+        "CRVAL1":  83,
+        "CRPIX1": 0,
+        "CDELT1": -0.0166667,
+        "CUNIT2": 'deg',
+        "CRVAL2": -2.0,
+        "CRPIX2": 0,
+        "CDELT2": 0.0166667,
+        "CTYPE1": 'GLON-CAR',
+        "CTYPE2": 'GLAT-CAR'}
 
-    data = np.zeros([400,400])
-    data[0:100,0:100] = 1
+    data = np.zeros([400, 400])
+    data[0:100, 0:100] = 1
     hdu = fits.PrimaryHDU(data=data, header=fits.Header(cards))
     hdu.writeto("test1.fits", overwrite=True)
 
-    data[:,:]=0
-    data[200:300,200:300] = 1
+    data[:, :] = 0
+    data[200:300, 200:300] = 1
     hdu = fits.PrimaryHDU(data=data, header=fits.Header(cards))
     hdu.writeto("test2.fits", overwrite=True)
 
-
-    #Now load template files and test their evaluation
-    shape1=SpatialTemplate_2D()
+    # Now load template files and test their evaluation
+    shape1 = SpatialTemplate_2D()
     shape1.load_file("test1.fits")
     shape1.K = 1
 
-    shape2=SpatialTemplate_2D()
+    shape2 = SpatialTemplate_2D()
     shape2.load_file("test2.fits")
     shape2.K = 1
 
     assert shape1.hash != shape2.hash
-        
-    assert np.all ( shape1.evaluate( [312, 306], [41, 41], [1,1], [40, 2]) == [1., 0.] ) 
-    assert np.all ( shape2.evaluate( [312, 306], [41, 41], [1,1], [40, 2]) ==  [0., 1.] ) 
-    assert np.all ( shape1.evaluate( [312, 306], [41, 41], [1,10], [40, 2]) == [1., 0.] ) 
-    assert np.all ( shape2.evaluate( [312, 306], [41, 41], [1,10], [40, 2]) ==  [0., 10.] ) 
 
+    assert np.all(shape1.evaluate(
+        [312, 306], [41, 41], [1, 1], [40, 2]) == [1., 0.])
+    assert np.all(shape2.evaluate(
+        [312, 306], [41, 41], [1, 1], [40, 2]) == [0., 1.])
+    assert np.all(shape1.evaluate(
+        [312, 306], [41, 41], [1, 10], [40, 2]) == [1., 0.])
+    assert np.all(shape2.evaluate(
+        [312, 306], [41, 41], [1, 10], [40, 2]) == [0., 10.])
 
     shape1.K = 1
     shape2.K = 1
-    assert np.all ( shape1( [312, 306], [41, 41]) == [1., 0.] )
-    assert np.all ( shape2( [312, 306], [41, 41]) == [0., 1.] )
+    assert np.all(shape1([312, 306], [41, 41]) == [1., 0.])
+    assert np.all(shape2([312, 306], [41, 41]) == [0., 1.])
 
     shape1.K = 1
     shape2.K = 10
-    assert np.all ( shape1( [312, 306], [41, 41]) == [1., 0.] )
-    assert np.all ( shape2( [312, 306], [41, 41]) == [0., 10.] )
+    assert np.all(shape1([312, 306], [41, 41]) == [1., 0.])
+    assert np.all(shape2([312, 306], [41, 41]) == [0., 10.])
 
     os.remove("test1.fits")
     os.remove("test2.fits")
-
-
