@@ -17,10 +17,9 @@ from astromodels.core.model import (CannotWriteModel, DuplicatedNode, Model,
                                     ModelFileExists)
 from astromodels.core.model_parser import *
 from astromodels.core.parameter import IndependentVariable, Parameter
-from astromodels.functions.functions import (Line, Powerlaw,
-                                             _ComplexTestFunction)
-from astromodels.functions.functions_2D import Gaussian_on_sphere
-from astromodels.functions.priors import Uniform_prior
+from astromodels.functions import (Gaussian_on_sphere, Line, Powerlaw,
+                                   Uniform_prior)
+from astromodels.functions.functions import _ComplexTestFunction
 from astromodels.sources.extended_source import ExtendedSource
 from astromodels.sources.particle_source import ParticleSource
 from astromodels.sources.point_source import PointSource
@@ -183,7 +182,8 @@ def test_constructor_with_many_point_sources():
 
     # Test with 200 point sources
 
-    many_p_sources = [_get_point_source("pts_source%i" % x) for x in range(200)]
+    many_p_sources = [_get_point_source(
+        "pts_source%i" % x) for x in range(200)]
 
     m = Model(*many_p_sources)
 
@@ -198,7 +198,8 @@ def test_constructor_with_many_extended_sources():
     _ = Model(ext)
 
     # Test with 200 extended sources
-    many_e_sources = [_get_extended_source("ext_source%i" % x) for x in range(200)]
+    many_e_sources = [_get_extended_source(
+        "ext_source%i" % x) for x in range(200)]
 
     m = Model(*many_e_sources)
 
@@ -207,11 +208,14 @@ def test_constructor_with_many_extended_sources():
 
 def test_constructor_with_mix():
 
-    many_p_sources = [_get_point_source("pts_source%i" % x) for x in range(200)]
+    many_p_sources = [_get_point_source(
+        "pts_source%i" % x) for x in range(200)]
 
-    many_e_sources = [_get_extended_source("ext_source%i" % x) for x in range(200)]
+    many_e_sources = [_get_extended_source(
+        "ext_source%i" % x) for x in range(200)]
 
-    many_part_sources = [_get_particle_source("part_source%i" % x) for x in range(200)]
+    many_part_sources = [_get_particle_source(
+        "part_source%i" % x) for x in range(200)]
 
     all_sources = []
     all_sources.extend(many_p_sources)
@@ -352,7 +356,8 @@ def test_links():
 
     n_free_before_link = len(m.free_parameters)
 
-    m.link(m.one.spectrum.main.Powerlaw.K, m.two.spectrum.main.Powerlaw.K, link_law)
+    m.link(m.one.spectrum.main.Powerlaw.K,
+           m.two.spectrum.main.Powerlaw.K, link_law)
 
     # The power law adds two parameters, but the link removes one, so
     assert len(m.free_parameters) - 1 == n_free_before_link
@@ -386,10 +391,10 @@ def test_links():
     assert m.ext_one.spectrum.main.Powerlaw.K.value == new_value
     # Remove the links at once
 
-    
-    m.unlink([m.one.spectrum.main.Powerlaw.K,m.ext_one.spectrum.main.Powerlaw.K])
-  
-  
+    m.unlink([m.one.spectrum.main.Powerlaw.K,
+              m.ext_one.spectrum.main.Powerlaw.K])
+
+
 def test_auto_unlink():
 
     mg = ModelGetter()
@@ -400,59 +405,55 @@ def test_auto_unlink():
 
     # Link as equal (default)
     m.link(m.one.spectrum.main.Powerlaw.K, m.two.spectrum.main.Powerlaw.K)
-    m.link(m.one.spectrum.main.Powerlaw.index, m.two.spectrum.main.Powerlaw.index)
+    m.link(m.one.spectrum.main.Powerlaw.index,
+           m.two.spectrum.main.Powerlaw.index)
 
     n_free_source2 = len(m.two.free_parameters)
 
-    #This should give a warning about automatically unlinking 2 parameters
+    # This should give a warning about automatically unlinking 2 parameters
     with pytest.warns(RuntimeWarning):
-        
+
         m.remove_source(m.two.name)
-    
+
     assert len(m.free_parameters) == n_free_before_link - n_free_source2
-    
 
     # Redo the same, but with a powerlaw law
 
     mg = ModelGetter()
-    
+
     m = mg.model
-    
+
     link_law = Powerlaw()
 
     link_law.K.value = 1.0
     link_law.index.value = -1.0
 
-    m.link(m.one.spectrum.main.Powerlaw.K, m.two.spectrum.main.Powerlaw.K, link_law)
+    m.link(m.one.spectrum.main.Powerlaw.K,
+           m.two.spectrum.main.Powerlaw.K, link_law)
 
     with pytest.warns(RuntimeWarning):
-        
-        m.remove_source(m.two.name)
-    
-    assert len(m.free_parameters) == n_free_before_link - n_free_source2
 
+        m.remove_source(m.two.name)
+
+    assert len(m.free_parameters) == n_free_before_link - n_free_source2
 
     # Redo the same, but with two linked parameters
 
     mg = ModelGetter()
-    
+
     m = mg.model
-    
-    m.link([m.one.spectrum.main.Powerlaw.K,m.ext_one.spectrum.main.Powerlaw.K],m.two.spectrum.main.Powerlaw.K)
+
+    m.link([m.one.spectrum.main.Powerlaw.K,
+            m.ext_one.spectrum.main.Powerlaw.K], m.two.spectrum.main.Powerlaw.K)
 
     with pytest.warns(RuntimeWarning):
-        
+
         m.remove_source(m.two.name)
-    
+
     assert len(m.free_parameters) == n_free_before_link - n_free_source2
 
-    
-    
-    
-
-
-    m.unlink([m.one.spectrum.main.Powerlaw.K, m.ext_one.spectrum.main.Powerlaw.K])
-
+    m.unlink([m.one.spectrum.main.Powerlaw.K,
+              m.ext_one.spectrum.main.Powerlaw.K])
 
 
 def test_external_parameters():
@@ -641,7 +642,8 @@ def test_input_output_with_complex_functions():
 
     my_particle_distribution.index = -1.52
 
-    electrons = ParticleSource("electrons", distribution_shape=my_particle_distribution)
+    electrons = ParticleSource(
+        "electrons", distribution_shape=my_particle_distribution)
 
     # Now set up the synch. spectrum for our source and the source itself
 
@@ -816,9 +818,11 @@ def test_3ML_interface():
     energies = np.logspace(3, 4, 100)
     fluxes = m.get_extended_source_fluxes(0, ra, dec, energies)
 
-    assert np.all(fluxes == list(m.extended_sources.values())[0](ra, dec, energies))
+    assert np.all(fluxes == list(m.extended_sources.values())
+                  [0](ra, dec, energies))
 
-    assert m.get_extended_source_name(0) == list(m.extended_sources.values())[0].name
+    assert m.get_extended_source_name(0) == list(
+        m.extended_sources.values())[0].name
 
     res = m.get_extended_source_boundaries(0)
 
@@ -836,7 +840,8 @@ def test_3ML_interface():
 
     assert np.all(fluxes == list(m.particle_sources.values())[0](energies))
 
-    assert m.get_particle_source_name(0) == list(m.particle_sources.values())[0].name
+    assert m.get_particle_source_name(0) == list(
+        m.particle_sources.values())[0].name
 
 
 def test_clone_model():
@@ -984,7 +989,8 @@ def test_time_domain_integration():
 
     effective_norm = old_div((F(10) - F(0)), 10.0)
 
-    expected_results = default_powerlaw(energies) * effective_norm  # type: np.ndarray
+    expected_results = default_powerlaw(
+        energies) * effective_norm  # type: np.ndarray
 
     assert np.allclose(expected_results, results)
 
