@@ -5,9 +5,9 @@ import numpy as np
 import pytest
 
 from astromodels.core.spectral_component import SpectralComponent
-from astromodels.functions.functions import Powerlaw, Exponential_cutoff, Log_parabola, Blackbody, Band
+from astromodels.functions import Powerlaw, Exponential_cutoff, Log_parabola, Blackbody, Band
 try:
-    from astromodels.functions.apec import TbAbs, PhAbs, WAbs
+    from astromodels.functions import TbAbs, PhAbs, WAbs
 
     has_abs_models = True
 
