@@ -4,8 +4,8 @@ import pytest
 import os
 import numpy as np
 
-from astromodels.functions.template_model import TemplateModel, TemplateModelFactory, MissingDataFile, XSPECTableModel
-from astromodels.functions.functions import Band, Powerlaw
+from astromodels.functions import TemplateModel, TemplateModelFactory, MissingDataFile, XSPECTableModel
+from astromodels.functions import Band, Powerlaw
 from astromodels import Model, PointSource, clone_model, load_model
 from astromodels.utils.data_files import _get_data_file_path
 
@@ -198,4 +198,4 @@ def test_xspec_table_model():
 
     xtm = XSPECTableModel(test_table)
 
-    xtm.to_table_model('xspectm_test', 'xspec model', overwrite=True)
\ No newline at end of file
+    xtm.to_table_model('xspectm_test', 'xspec model', overwrite=True)
